@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2006,2007,2008,2009,2010,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2006,2007,2008,2009,2010,2012,2013,2014,2016,2017
+ *               Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -53,6 +54,7 @@ KeyServer::KeyServer(QWidget *parent, KGpgItemModel *model, const bool autoclose
 	page->kCBexportks->addItems(serverlist);
 	page->kCBimportks->addItems(serverlist);
 	page->qLEimportid->setFocus();
+	page->Buttonsearch->setDefault(true);
 
 	connect(page->buttonBox, &QDialogButtonBox::rejected, this, &KeyServer::accept);
 	connect(page->Buttonimport, &QPushButton::clicked, this, &KeyServer::slotImport);
@@ -61,7 +63,6 @@ KeyServer::KeyServer(QWidget *parent, KGpgItemModel *model, const bool autoclose
 	connect(page->buttonBox, &QDialogButtonBox::accepted, this, &KeyServer::slotOk);
 	connect(page->cBproxyI, &QCheckBox::toggled, this, &KeyServer::slotEnableProxyI);
 	connect(page->cBproxyE, &QCheckBox::toggled, this, &KeyServer::slotEnableProxyE);
-	connect(page->qLEimportid,  &QLineEdit::returnPressed, this, &KeyServer::slotSearch);
 	connect(page->qLEimportid, &QLineEdit::textChanged, this, &KeyServer::slotTextChanged);
 
 	page->cBproxyI->setChecked(KGpgSettings::useProxy());
